package me.mrletsplay.videobase;

import java.nio.file.Path;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import me.mrletsplay.simplehttpserver.http.cors.CorsConfiguration;
import me.mrletsplay.simplehttpserver.http.server.HttpServer;
import me.mrletsplay.videobase.library.Library;
import me.mrletsplay.videobase.rest.LibraryAPI;
import me.mrletsplay.videobase.util.Hash;

public class VideoBase {

	public static final Logger LOGGER = LoggerFactory.getLogger(VideoBase.class.getName());

	private static ScheduledExecutorService executor;
	private static Library library;

	public static void main(String[] args) {
		executor = Executors.newScheduledThreadPool(0);

		// Verify hash is working
		Hash.hash("test");

		loadLibrary();
		executor.scheduleWithFixedDelay(VideoBase::loadLibrary, 10, 10, TimeUnit.MINUTES);

		HttpServer server = new HttpServer(HttpServer.newConfigurationBuilder()
			.hostBindAll()
			.port(6969)
			.poolSize(20)
			.ioWorkers(3)
//			.logger(NOPLogger.NOP_LOGGER)
			.defaultCorsConfiguration(CorsConfiguration.createAllowAll())
			.create());

		new LibraryAPI().register(server.getDocumentProvider());

		server.start();
	}

	public static Library getLibrary() {
		return library;
	}

	private static void loadLibrary() {
		library = Library.load(Path.of("/mnt/wd4tb/Files/ytdl/Aliensrock/"));

		System.out.println(library.getVideos());
	}

}
